/*  duct_p.c  ******************************\ 
*  Cross-section flow parameters averaging  *
\*******************************************/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>

#define K  1.4  /* ratio of specific heats */


/**********
* AVERAGE *   Averaging of cross-sectional flow parameters 
**********/ 
void Average(float M1, /*--------------------------------*/
             float J1, /*  1D integral fluxes of m, m, e */
	     float I1, /*--------------------------------*/
	     float *P, /*--------------------------------*/
	     float *R, /*  primitive 1D flow parameters  */
	     float *U) /*--------------------------------*/
{
FILE *pF;
double a, b, c, D;

  a = 0.5 - K / (K - 1.);
  b = J1 / (K - 1.);
  c = J1 * J1 / 2 - I1 * M1;
  D = b * b - 4 * a * c;
  *P = (- b - sqrt(D)) / (2. * a);
  *U = (J1 - *P) / M1;
  *R = M1 / *U;

  printf("P = %f\nR = %f\nU = %f\n", *P, *R, *U);
	
} /* end Average() */


/*********
*  READ  *   Extracts the next float from string
*********/
void Read( char *src, char *dest )
{
  int i, j;	char med[80]; i=0;
  while (src[i] != ' ') {
    dest[i] = src[i]; 
    i++;
  } 
  dest[i+1]= '\n';
  strcpy(med, &src[i]);
  i=0;
  while (med[i++] == ' ') 
  strcpy(src, &med[i]);
} /* end Read() */


/*********
*  MAIN  *
*********/
int main(int argc, char *argv[])
{
unsigned number, number_start, number_end, counter = 0;
float RU = 0., RUUP = 0., RUH = 0., TAU = 0., P, R, U, v1, v2, v3, v4;
FILE *pF;
char  str1[80], str2[80];

  /*-- input start & end --*/
  printf("number_start = "); scanf("%d", &number_start);
  printf("number_end   = "); scanf("%d", &number_end);
		
  /*-- open file --*/
  if ((pF = fopen("probes.txt" ,"r" )) == NULL) {
    fprintf(stderr, "%s: Cannot open \"probes.txt\" \n", argv[0]);
    exit(-1);
  }
  /*-- read --*/	
  while(1) {
    if (fgets(str1, 80, pF) != NULL) {
      sscanf(str1, "%d %f %f %f %f", &number, &v1, &v2, &v3, &v4);
      if (number < number_start) 
	continue;
      if (number > number_end) 
	break;
      RU += v1;
      RUUP += v2;
      RUH += v3;
      TAU += v4;
      counter++;
    }
    else {
      fprintf(stderr, "%s: Error reading file\n", argv[0]);
      exit( -1 );
    }
  } 
  /*-- close file --*/
  fclose(pF);

  /*-- average --*/
  RU  /= (float)counter, RUUP /= (float)counter;
  RUH /= (float)counter, TAU  /= (float)counter;
  Average(RU, RUUP, RUH, &P, &R, &U);
		
  /*-- open file --*/
  if ((pF = fopen("duct.1D", "a")) == NULL ) {
    fprintf(stderr, "%s: Cannot open \"duct.1D\" \n", argv[0]);
    exit(-1);
  }
  /*-- write P, R, U and mean wall shear stress TAU */
  fprintf(pF, "%d...%d: \n  P = %f, R = %f, U = %f, tau_w = %f\n",
	   number_start, number_end, P, R, U, TAU);
  /*-- close file --*/
  fclose(pF);
		
  return 0;
		
} /* end main() */

/* end duct_p.c */
