/* duct_pp.c **********************\
*                                  *
*  v. 0.3, 16 March 2001           *
*                                  *  
*     Reynolds/Favre averaging     *
*  using computed DNS or LES data  *
*       for square duct flow	   *
*                                  *
\**********************************/

#include <stdlib.h>
#include <stdio.h>


float *ArrayAllocMem(unsigned size) 
{
  float *x;

  if ((x = (float*)malloc(sizeof(float)*size)) == NULL) {
    fprintf(stderr, "can't allocate memeory.\n");
    exit(-1);
  }
   
  return x;
   
} /* end ArrayAllocMem() */  

/***********
*   MAIN   *
***********/
int main(int argc, char *argv[])
{
unsigned HIG, step, stepStart, stepEnd, i, j;
float *probeR, *probeRU, *R1, *RU1;
FILE *pFprobes, *pFprofile;

  /*--- parameters acquisition ---*/
  printf("stepStart = "); scanf("%d", &stepStart);
  printf("stepEnd = ");   scanf("%d", &stepEnd);  
  printf("HIG = ");       scanf("%d", &HIG);  
  
  /*--- allocate memory and zero init some arrays ---*/
  /* for buffer arrays */
  probeR  = ArrayAllocMem(HIG);
  probeRU = ArrayAllocMem(HIG);
  R1      = ArrayAllocMem(HIG);
  RU1     = ArrayAllocMem(HIG);
  
  for (i = 0; i < HIG; i++) 
    R1[i] = RU1[i] = 0.;

  /*--- open file with probes data ---*/
  if((pFprobes = fopen("probes.bin", "rb")) == NULL) { 
    fprintf(stderr, "%s: Can't open file \"probes.bin\".\n", argv[0]); 
    exit(-1); 
  }

  /*--- read numstep readings ---*/
  for (i = 0;; i++) {
  
    /* read step */
    fread(&step, sizeof(step), 1, pFprobes);
	
    /* finish */
    if (step > stepEnd)
      break;
	  
    /* simply read, not add */
    if (step < stepStart) { 
      fread(probeR,  sizeof(probeR) *HIG, 1, pFprobes);
      fread(probeRU, sizeof(probeRU)*HIG, 1, pFprobes);
    } 
    /* print step out and read data */	
    else{
      printf("step = %d\n", step);
      fread(probeR,  sizeof(float)*HIG, 1, pFprobes);
      fread(probeRU, sizeof(float)*HIG, 1, pFprobes);
      for (j = 0; j < HIG; j++) { 
	R1[j] += probeR[j]; 
	RU1[j] += probeRU[j];
      }
    }
	
  } /* end for() */

  /*--- close file with probes data ---*/
  fclose(pFprobes);

  /*--- Favre average (here RU1 means Favre averaged U1 ) ---*/
  for (j = 0; j < HIG; j++)
    RU1[j] /= R1[j];

  /*--- write streamwise velocity profile ---*/
  if ((pFprofile = fopen("probes.dat", "w")) == NULL) { 
    fprintf(stderr, "%s: Can't open \"probes.dat\".\n", argv[0]); 
    exit(-1); 
  }

  fprintf(pFprofile, "%d\n1\n", HIG+2);
  fprintf(pFprofile, "%f %3.2f \n", -0.00001, 0.);
  /**/
  for (j = 0; j < HIG; j++)
    fprintf( pFprofile, "%d %3.2f \n", j, RU1[j] );
  /**/
  fprintf(pFprofile, "%f %3.2f \n", HIG-1+0.00001, 300.);
  fclose(pFprofile);

  return 0;

} /* end main() */

/* end duct_pp.c */
